diff --git a/Assets/Prefabs/Lobby/LobbyUI.prefab b/Assets/Prefabs/Lobby/LobbyUI.prefab
index 87f5f5a..58f8524 100644
--- a/Assets/Prefabs/Lobby/LobbyUI.prefab
+++ b/Assets/Prefabs/Lobby/LobbyUI.prefab
@@ -1580,6 +1580,41 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!1 &621579691688463782
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 6274243578080049737}
+ m_Layer: 0
+ m_Name: ML
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &6274243578080049737
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 621579691688463782}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 3
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 250, y: 500}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &756786560135461277
GameObject:
m_ObjectHideFlags: 0
@@ -2325,6 +2360,7 @@ RectTransform:
- {fileID: 697221495148640912}
- {fileID: 1354363586255247205}
- {fileID: 1795553190}
+ - {fileID: 7144776162630519979}
m_Father: {fileID: 5150736904915817095}
m_RootOrder: 0
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
@@ -3813,6 +3849,15 @@ MonoBehaviour:
- {x: -7, y: -17.5, z: 0}
- {x: -21.5, y: -1.4, z: 0}
tooltip: {fileID: 0}
+ postItPos:
+ - {fileID: 2505553911567252947}
+ - {fileID: 3404664521133099042}
+ - {fileID: 6389228003972979548}
+ - {fileID: 6274243578080049737}
+ - {fileID: 3074451421150331547}
+ - {fileID: 2267936738958048773}
+ - {fileID: 1555351020459058610}
+ - {fileID: 33940591754875552}
itemBG:
- {fileID: 7627111236641680476, guid: 81773d5ce89537c4b920f5caf313c271, type: 3}
- {fileID: 1118100524556035779, guid: 81773d5ce89537c4b920f5caf313c271, type: 3}
@@ -4238,6 +4283,41 @@ MonoBehaviour:
m_FillOrigin: 0
m_UseSpriteMesh: 0
m_PixelsPerUnitMultiplier: 1
+--- !u!1 &3225299937271858721
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 3404664521133099042}
+ m_Layer: 0
+ m_Name: TM
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &3404664521133099042
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 3225299937271858721}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 1
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 450, y: 700}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &3229267049952274861
GameObject:
m_ObjectHideFlags: 0
@@ -5021,6 +5101,41 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 3975031492042563123}
m_CullTransparentMesh: 1
+--- !u!1 &4017152994527882622
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 2505553911567252947}
+ m_Layer: 0
+ m_Name: TL
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &2505553911567252947
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 4017152994527882622}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 0
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 250, y: 700}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &4087062188595398825
GameObject:
m_ObjectHideFlags: 0
@@ -5322,6 +5437,41 @@ RectTransform:
m_AnchoredPosition: {x: 0, y: 0}
m_SizeDelta: {x: 0, y: -20}
m_Pivot: {x: 0.5, y: 0.5}
+--- !u!1 &4299687742105912241
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 2267936738958048773}
+ m_Layer: 0
+ m_Name: MR
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &2267936738958048773
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 4299687742105912241}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 5
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 650, y: 500}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &4415466681190630401
GameObject:
m_ObjectHideFlags: 0
@@ -6195,7 +6345,7 @@ GameObject:
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 1
+ m_IsActive: 0
--- !u!4 &7810498348320998331
Transform:
m_ObjectHideFlags: 0
@@ -6241,6 +6391,49 @@ MonoBehaviour:
bumper: {fileID: -1299129274275613984, guid: e50aa6ca2e43edf4dbd8ea82e0c022c9, type: 3}
slime: {fileID: -5902826298676525234, guid: e50aa6ca2e43edf4dbd8ea82e0c022c9, type: 3}
hail: {fileID: 104298233470097908, guid: e50aa6ca2e43edf4dbd8ea82e0c022c9, type: 3}
+--- !u!1 &5374683307395483390
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 7144776162630519979}
+ m_Layer: 0
+ m_Name: ItemPostItPositions
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &7144776162630519979
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 5374683307395483390}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children:
+ - {fileID: 2505553911567252947}
+ - {fileID: 3404664521133099042}
+ - {fileID: 6389228003972979548}
+ - {fileID: 6274243578080049737}
+ - {fileID: 3074451421150331547}
+ - {fileID: 2267936738958048773}
+ - {fileID: 1555351020459058610}
+ - {fileID: 33940591754875552}
+ m_Father: {fileID: 7654765330931903944}
+ m_RootOrder: 5
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: -600, y: -500}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &5411663148713234339
GameObject:
m_ObjectHideFlags: 0
@@ -6790,6 +6983,41 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!1 &7718874904397614007
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 1555351020459058610}
+ m_Layer: 0
+ m_Name: BL
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &1555351020459058610
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 7718874904397614007}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 6
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 250, y: 300}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &7765521373850063248
GameObject:
m_ObjectHideFlags: 0
@@ -6957,6 +7185,41 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!1 &8112126606943270064
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 6389228003972979548}
+ m_Layer: 0
+ m_Name: TR
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &6389228003972979548
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 8112126606943270064}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 2
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 650, y: 700}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &8135969196951055869
GameObject:
m_ObjectHideFlags: 0
@@ -7238,6 +7501,41 @@ RectTransform:
m_AnchoredPosition: {x: -3.035, y: 209}
m_SizeDelta: {x: 106.07, y: 106.069}
m_Pivot: {x: 0.5, y: 0.5}
+--- !u!1 &8875886525865017711
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 33940591754875552}
+ m_Layer: 0
+ m_Name: BM
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &33940591754875552
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 8875886525865017711}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 7
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 450, y: 300}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1 &9053828494004578490
GameObject:
m_ObjectHideFlags: 0
@@ -7372,6 +7670,41 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!1 &9067505099715554357
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 3074451421150331547}
+ m_Layer: 0
+ m_Name: MM
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &3074451421150331547
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 9067505099715554357}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 7144776162630519979}
+ m_RootOrder: 4
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 450, y: 500}
+ m_SizeDelta: {x: 100, y: 100}
+ m_Pivot: {x: 0.5, y: 0.5}
--- !u!1001 &774296663448789634
PrefabInstance:
m_ObjectHideFlags: 0
@@ -7481,6 +7814,11 @@ PrefabInstance:
objectReference: {fileID: 6766089182942896627}
m_RemovedComponents: []
m_SourcePrefab: {fileID: 100100000, guid: b011977908109f5499facd442c54a381, type: 3}
+--- !u!1 &1072192668118827015 stripped
+GameObject:
+ m_CorrespondingSourceObject: {fileID: 315229139951084165, guid: b011977908109f5499facd442c54a381, type: 3}
+ m_PrefabInstance: {fileID: 774296663448789634}
+ m_PrefabAsset: {fileID: 0}
--- !u!1 &4679530088279849249 stripped
GameObject:
m_CorrespondingSourceObject: {fileID: 5354741907627875235, guid: b011977908109f5499facd442c54a381, type: 3}
@@ -7513,11 +7851,6 @@ MonoBehaviour:
m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
m_Name:
m_EditorClassIdentifier:
---- !u!1 &1072192668118827015 stripped
-GameObject:
- m_CorrespondingSourceObject: {fileID: 315229139951084165, guid: b011977908109f5499facd442c54a381, type: 3}
- m_PrefabInstance: {fileID: 774296663448789634}
- m_PrefabAsset: {fileID: 0}
--- !u!1 &5411803177918343445 stripped
GameObject:
m_CorrespondingSourceObject: {fileID: 4729990066779556759, guid: b011977908109f5499facd442c54a381, type: 3}
@@ -7919,11 +8252,6 @@ PrefabInstance:
objectReference: {fileID: 0}
m_RemovedComponents: []
m_SourcePrefab: {fileID: 100100000, guid: 25b0bd1c83713d44ab76eaa07a6357fa, type: 3}
---- !u!224 &3732651221136882027 stripped
-RectTransform:
- m_CorrespondingSourceObject: {fileID: 2004584391902020887, guid: 25b0bd1c83713d44ab76eaa07a6357fa, type: 3}
- m_PrefabInstance: {fileID: 2890392183042899068}
- m_PrefabAsset: {fileID: 0}
--- !u!114 &5410293111695408891 stripped
MonoBehaviour:
m_CorrespondingSourceObject: {fileID: 7136380821082899079, guid: 25b0bd1c83713d44ab76eaa07a6357fa, type: 3}
@@ -7935,6 +8263,11 @@ MonoBehaviour:
m_Script: {fileID: 11500000, guid: 311c1a64d12df464ab0b856d2aa3e5ae, type: 3}
m_Name:
m_EditorClassIdentifier:
+--- !u!224 &3732651221136882027 stripped
+RectTransform:
+ m_CorrespondingSourceObject: {fileID: 2004584391902020887, guid: 25b0bd1c83713d44ab76eaa07a6357fa, type: 3}
+ m_PrefabInstance: {fileID: 2890392183042899068}
+ m_PrefabAsset: {fileID: 0}
--- !u!1001 &6471307727058244567
PrefabInstance:
m_ObjectHideFlags: 0
diff --git a/Assets/Prefabs/Player/NetworkSMPlayerPrefab.prefab b/Assets/Prefabs/Player/NetworkSMPlayerPrefab.prefab
index 00fbb08..0bfd1d4 100644
--- a/Assets/Prefabs/Player/NetworkSMPlayerPrefab.prefab
+++ b/Assets/Prefabs/Player/NetworkSMPlayerPrefab.prefab
@@ -5840,7 +5840,7 @@ Camera:
m_Depth: -1
m_CullingMask:
serializedVersion: 2
- m_Bits: 158431
+ m_Bits: 682719
m_RenderingPath: -1
m_TargetTexture: {fileID: 0}
m_TargetDisplay: 0
diff --git a/Assets/Scenes/Controls.unity b/Assets/Scenes/Controls.unity
index f7d9b27..069505f 100644
--- a/Assets/Scenes/Controls.unity
+++ b/Assets/Scenes/Controls.unity
@@ -347,140 +347,6 @@ Transform:
m_Father: {fileID: 0}
m_RootOrder: 3
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
---- !u!1 &125333469
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 125333470}
- - component: {fileID: 125333472}
- - component: {fileID: 125333471}
- m_Layer: 5
- m_Name: To-Do
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &125333470
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 125333469}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 2.0870254, y: 2.0267, z: 1}
- m_Children: []
- m_Father: {fileID: 1652436829}
- m_RootOrder: 0
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 409, y: -131.14331}
- m_SizeDelta: {x: 591.0192, y: 54.5584}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &125333471
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 125333469}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_text: TO-DO
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4281479730
- m_fontColor: {r: 0.19607845, g: 0.19607845, b: 0.19607845, a: 1}
- m_enableVertexGradient: 0
- m_colorMode: 3
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_StyleSheet: {fileID: 0}
- m_TextStyleHashCode: -1183493901
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_fontSize: 24
- m_fontSizeBase: 24
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_HorizontalAlignment: 1
- m_VerticalAlignment: 256
- m_textAlignment: 65535
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_linkedTextComponent: {fileID: 0}
- parentLinkedComponent: {fileID: 0}
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 1
- m_isCullingEnabled: 0
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_IsTextObjectScaleStatic: 0
- m_VertexBufferAutoSizeReduction: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_hasFontAssetChanged: 0
- m_baseMaterial: {fileID: 0}
- m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!222 &125333472
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 125333469}
- m_CullTransparentMesh: 1
--- !u!1 &138218807
GameObject:
m_ObjectHideFlags: 0
@@ -2144,140 +2010,6 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 474284780}
m_CullTransparentMesh: 1
---- !u!1 &606199964
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 606199965}
- - component: {fileID: 606199967}
- - component: {fileID: 606199966}
- m_Layer: 5
- m_Name: Placing Objects
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &606199965
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 606199964}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 2.0870254, y: 2.0267, z: 1}
- m_Children: []
- m_Father: {fileID: 646467613}
- m_RootOrder: 1
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 390.86816, y: -190}
- m_SizeDelta: {x: 591.0192, y: 54.5584}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &606199966
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 606199964}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_text: 'Placing Objects: Left Mouse Button.'
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4281479730
- m_fontColor: {r: 0.19607845, g: 0.19607845, b: 0.19607845, a: 1}
- m_enableVertexGradient: 0
- m_colorMode: 3
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_StyleSheet: {fileID: 0}
- m_TextStyleHashCode: -1183493901
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_fontSize: 24
- m_fontSizeBase: 24
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_HorizontalAlignment: 1
- m_VerticalAlignment: 256
- m_textAlignment: 65535
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_linkedTextComponent: {fileID: 0}
- parentLinkedComponent: {fileID: 0}
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 1
- m_isCullingEnabled: 0
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_IsTextObjectScaleStatic: 0
- m_VertexBufferAutoSizeReduction: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_hasFontAssetChanged: 0
- m_baseMaterial: {fileID: 0}
- m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!222 &606199967
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 606199964}
- m_CullTransparentMesh: 1
--- !u!1 &607428696
GameObject:
m_ObjectHideFlags: 0
@@ -2568,7 +2300,6 @@ RectTransform:
- {fileID: 607428697}
- {fileID: 646467613}
- {fileID: 1652436829}
- - {fileID: 1505670058}
m_Father: {fileID: 1900436314}
m_RootOrder: 4
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
@@ -2587,7 +2318,6 @@ GameObject:
m_Component:
- component: {fileID: 646467613}
- component: {fileID: 646467615}
- - component: {fileID: 646467614}
m_Layer: 5
m_Name: Keyboard
m_TagString: Untagged
@@ -2605,9 +2335,7 @@ RectTransform:
m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
m_LocalPosition: {x: 0, y: 0, z: 0}
m_LocalScale: {x: 1, y: 1, z: 1}
- m_Children:
- - {fileID: 1987103242}
- - {fileID: 606199965}
+ m_Children: []
m_Father: {fileID: 631858743}
m_RootOrder: 1
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
@@ -2616,40 +2344,6 @@ RectTransform:
m_AnchoredPosition: {x: -645, y: 320}
m_SizeDelta: {x: 160, y: 30}
m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &646467614
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 646467612}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 5f7201a12d95ffc409449d95f23cf332, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 0.19607843, g: 0.19607843, b: 0.19607843, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_FontData:
- m_Font: {fileID: 10102, guid: 0000000000000000e000000000000000, type: 0}
- m_FontSize: 100
- m_FontStyle: 0
- m_BestFit: 0
- m_MinSize: 1
- m_MaxSize: 100
- m_Alignment: 4
- m_AlignByGeometry: 0
- m_RichText: 1
- m_HorizontalOverflow: 1
- m_VerticalOverflow: 1
- m_LineSpacing: 1
- m_Text: Keyboard
--- !u!222 &646467615
CanvasRenderer:
m_ObjectHideFlags: 0
@@ -5195,85 +4889,6 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 1156148212}
m_CullTransparentMesh: 1
---- !u!1 &1311407004
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 1311407005}
- - component: {fileID: 1311407007}
- - component: {fileID: 1311407006}
- m_Layer: 5
- m_Name: Text
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &1311407005
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1311407004}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_Children: []
- m_Father: {fileID: 1505670058}
- m_RootOrder: 0
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0, y: 0}
- m_AnchorMax: {x: 1, y: 1}
- m_AnchoredPosition: {x: 0, y: 0}
- m_SizeDelta: {x: 0, y: 0}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &1311407006
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1311407004}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 5f7201a12d95ffc409449d95f23cf332, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 0.19607843, g: 0.19607843, b: 0.19607843, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_FontData:
- m_Font: {fileID: 10102, guid: 0000000000000000e000000000000000, type: 0}
- m_FontSize: 50
- m_FontStyle: 0
- m_BestFit: 0
- m_MinSize: 0
- m_MaxSize: 50
- m_Alignment: 4
- m_AlignByGeometry: 0
- m_RichText: 1
- m_HorizontalOverflow: 0
- m_VerticalOverflow: 0
- m_LineSpacing: 1
- m_Text: Runner Controls
---- !u!222 &1311407007
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1311407004}
- m_CullTransparentMesh: 1
--- !u!1 &1322325983
GameObject:
m_ObjectHideFlags: 0
@@ -5689,203 +5304,6 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 1453651971}
m_CullTransparentMesh: 1
---- !u!1 &1505670057
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 1505670058}
- - component: {fileID: 1505670062}
- - component: {fileID: 1505670061}
- - component: {fileID: 1505670060}
- - component: {fileID: 1505670059}
- - component: {fileID: 1505670064}
- - component: {fileID: 1505670063}
- m_Layer: 5
- m_Name: Runner
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &1505670058
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_Children:
- - {fileID: 1311407005}
- m_Father: {fileID: 631858743}
- m_RootOrder: 3
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: -862, y: -447}
- m_SizeDelta: {x: 200, y: 200}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &1505670059
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 62325ff0066151a44acb4cd23f6045b5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- currentMenu: {fileID: 631858742}
- nextMenu: {fileID: 1583569333}
---- !u!114 &1505670060
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 4e29b1a8efbd4b44bb3f3716e73f07ff, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Navigation:
- m_Mode: 3
- m_WrapAround: 0
- m_SelectOnUp: {fileID: 0}
- m_SelectOnDown: {fileID: 0}
- m_SelectOnLeft: {fileID: 0}
- m_SelectOnRight: {fileID: 0}
- m_Transition: 1
- m_Colors:
- m_NormalColor: {r: 1, g: 1, b: 1, a: 1}
- m_HighlightedColor: {r: 0.9607843, g: 0.9607843, b: 0.9607843, a: 1}
- m_PressedColor: {r: 0.78431374, g: 0.78431374, b: 0.78431374, a: 1}
- m_SelectedColor: {r: 0.9607843, g: 0.9607843, b: 0.9607843, a: 1}
- m_DisabledColor: {r: 0.78431374, g: 0.78431374, b: 0.78431374, a: 0.5019608}
- m_ColorMultiplier: 1
- m_FadeDuration: 0.1
- m_SpriteState:
- m_HighlightedSprite: {fileID: 0}
- m_PressedSprite: {fileID: 0}
- m_SelectedSprite: {fileID: 0}
- m_DisabledSprite: {fileID: 0}
- m_AnimationTriggers:
- m_NormalTrigger: Normal
- m_HighlightedTrigger: Highlighted
- m_PressedTrigger: Pressed
- m_SelectedTrigger: Selected
- m_DisabledTrigger: Disabled
- m_Interactable: 1
- m_TargetGraphic: {fileID: 1505670061}
- m_OnClick:
- m_PersistentCalls:
- m_Calls:
- - m_Target: {fileID: 1505670059}
- m_TargetAssemblyTypeName: SwitchMenuControls, Assembly-CSharp
- m_MethodName: enable
- m_Mode: 1
- m_Arguments:
- m_ObjectArgument: {fileID: 0}
- m_ObjectArgumentAssemblyTypeName: UnityEngine.Object, UnityEngine
- m_IntArgument: 0
- m_FloatArgument: 0
- m_StringArgument:
- m_BoolArgument: 0
- m_CallState: 2
---- !u!114 &1505670061
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: fe87c0e1cc204ed48ad3b37840f39efc, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_Sprite: {fileID: 10905, guid: 0000000000000000f000000000000000, type: 0}
- m_Type: 1
- m_PreserveAspect: 0
- m_FillCenter: 1
- m_FillMethod: 4
- m_FillAmount: 1
- m_FillClockwise: 1
- m_FillOrigin: 0
- m_UseSpriteMesh: 0
- m_PixelsPerUnitMultiplier: 1
---- !u!222 &1505670062
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_CullTransparentMesh: 1
---- !u!50 &1505670063
-Rigidbody2D:
- serializedVersion: 4
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_BodyType: 0
- m_Simulated: 1
- m_UseFullKinematicContacts: 0
- m_UseAutoMass: 0
- m_Mass: 1
- m_LinearDrag: 0
- m_AngularDrag: 0.05
- m_GravityScale: 0
- m_Material: {fileID: 0}
- m_Interpolate: 0
- m_SleepingMode: 0
- m_CollisionDetection: 1
- m_Constraints: 0
---- !u!61 &1505670064
-BoxCollider2D:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1505670057}
- m_Enabled: 1
- m_Density: 1
- m_Material: {fileID: 0}
- m_IsTrigger: 1
- m_UsedByEffector: 0
- m_UsedByComposite: 0
- m_Offset: {x: 0, y: 0}
- m_SpriteTilingProperty:
- border: {x: 0, y: 0, z: 0, w: 0}
- pivot: {x: 0, y: 0}
- oldSize: {x: 0, y: 0}
- newSize: {x: 0, y: 0}
- adaptiveTilingThreshold: 0
- drawMode: 0
- adaptiveTiling: 0
- m_AutoTiling: 0
- serializedVersion: 2
- m_Size: {x: 200, y: 200}
- m_EdgeRadius: 0
--- !u!1 &1514946354
GameObject:
m_ObjectHideFlags: 0
@@ -6202,6 +5620,140 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 1528680754}
m_CullTransparentMesh: 1
+--- !u!1 &1529363943
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 1529363944}
+ - component: {fileID: 1529363946}
+ - component: {fileID: 1529363945}
+ m_Layer: 5
+ m_Name: BindableExplain
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &1529363944
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1529363943}
+ m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 1782548923}
+ m_RootOrder: 1
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 0, y: -789}
+ m_SizeDelta: {x: 800, y: 50}
+ m_Pivot: {x: 0.5, y: 0.5}
+--- !u!114 &1529363945
+MonoBehaviour:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1529363943}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ m_Material: {fileID: 0}
+ m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_RaycastTarget: 1
+ m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
+ m_Maskable: 1
+ m_OnCullStateChanged:
+ m_PersistentCalls:
+ m_Calls: []
+ m_text: Click On The Keys & Press Either E,Q,F,R, or Shift to Rebind Them.
+ m_isRightToLeft: 0
+ m_fontAsset: {fileID: 11400000, guid: c9c6ab728bbf8974783d3354922a042f, type: 2}
+ m_sharedMaterial: {fileID: -1126714427571281196, guid: c9c6ab728bbf8974783d3354922a042f, type: 2}
+ m_fontSharedMaterials: []
+ m_fontMaterial: {fileID: 0}
+ m_fontMaterials: []
+ m_fontColor32:
+ serializedVersion: 2
+ rgba: 4278190080
+ m_fontColor: {r: 0, g: 0, b: 0, a: 1}
+ m_enableVertexGradient: 0
+ m_colorMode: 3
+ m_fontColorGradient:
+ topLeft: {r: 1, g: 1, b: 1, a: 1}
+ topRight: {r: 1, g: 1, b: 1, a: 1}
+ bottomLeft: {r: 1, g: 1, b: 1, a: 1}
+ bottomRight: {r: 1, g: 1, b: 1, a: 1}
+ m_fontColorGradientPreset: {fileID: 0}
+ m_spriteAsset: {fileID: 0}
+ m_tintAllSprites: 0
+ m_StyleSheet: {fileID: 0}
+ m_TextStyleHashCode: -1183493901
+ m_overrideHtmlColors: 0
+ m_faceColor:
+ serializedVersion: 2
+ rgba: 4294967295
+ m_fontSize: 60
+ m_fontSizeBase: 60
+ m_fontWeight: 400
+ m_enableAutoSizing: 0
+ m_fontSizeMin: 18
+ m_fontSizeMax: 72
+ m_fontStyle: 0
+ m_HorizontalAlignment: 2
+ m_VerticalAlignment: 512
+ m_textAlignment: 65535
+ m_characterSpacing: 0
+ m_wordSpacing: 0
+ m_lineSpacing: 0
+ m_lineSpacingMax: 0
+ m_paragraphSpacing: 0
+ m_charWidthMaxAdj: 0
+ m_enableWordWrapping: 1
+ m_wordWrappingRatios: 0.4
+ m_overflowMode: 0
+ m_linkedTextComponent: {fileID: 0}
+ parentLinkedComponent: {fileID: 0}
+ m_enableKerning: 1
+ m_enableExtraPadding: 0
+ checkPaddingRequired: 0
+ m_isRichText: 1
+ m_parseCtrlCharacters: 1
+ m_isOrthographic: 1
+ m_isCullingEnabled: 0
+ m_horizontalMapping: 0
+ m_verticalMapping: 0
+ m_uvLineOffset: 0
+ m_geometrySortingOrder: 0
+ m_IsTextObjectScaleStatic: 0
+ m_VertexBufferAutoSizeReduction: 0
+ m_useMaxVisibleDescender: 1
+ m_pageToDisplay: 1
+ m_margin: {x: 0, y: 0, z: 0, w: 0}
+ m_isUsingLegacyAnimationComponent: 0
+ m_isVolumetricText: 0
+ m_hasFontAssetChanged: 0
+ m_baseMaterial: {fileID: 0}
+ m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!222 &1529363946
+CanvasRenderer:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1529363943}
+ m_CullTransparentMesh: 1
--- !u!1 &1583569333
GameObject:
m_ObjectHideFlags: 0
@@ -6682,7 +6234,6 @@ GameObject:
m_Component:
- component: {fileID: 1652436829}
- component: {fileID: 1652436831}
- - component: {fileID: 1652436830}
m_Layer: 5
m_Name: GamePad
m_TagString: Untagged
@@ -6700,8 +6251,7 @@ RectTransform:
m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
m_LocalPosition: {x: 0, y: 0, z: 0}
m_LocalScale: {x: 1, y: 1, z: 1}
- m_Children:
- - {fileID: 125333470}
+ m_Children: []
m_Father: {fileID: 631858743}
m_RootOrder: 2
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
@@ -6710,40 +6260,6 @@ RectTransform:
m_AnchoredPosition: {x: 274.86816, y: 321.14337}
m_SizeDelta: {x: 160, y: 30}
m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &1652436830
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1652436828}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 5f7201a12d95ffc409449d95f23cf332, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 0.19607843, g: 0.19607843, b: 0.19607843, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_FontData:
- m_Font: {fileID: 10102, guid: 0000000000000000e000000000000000, type: 0}
- m_FontSize: 100
- m_FontStyle: 0
- m_BestFit: 0
- m_MinSize: 1
- m_MaxSize: 100
- m_Alignment: 4
- m_AlignByGeometry: 0
- m_RichText: 1
- m_HorizontalOverflow: 1
- m_VerticalOverflow: 1
- m_LineSpacing: 1
- m_Text: GamePad
--- !u!222 &1652436831
CanvasRenderer:
m_ObjectHideFlags: 0
@@ -7202,6 +6718,7 @@ RectTransform:
m_LocalScale: {x: 1, y: 1, z: 1}
m_Children:
- {fileID: 913500272}
+ - {fileID: 1529363944}
m_Father: {fileID: 1583569334}
m_RootOrder: 1
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
@@ -7873,142 +7390,6 @@ CanvasRenderer:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 1911009451}
m_CullTransparentMesh: 1
---- !u!1 &1987103241
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 1987103242}
- - component: {fileID: 1987103244}
- - component: {fileID: 1987103243}
- m_Layer: 5
- m_Name: Movement
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &1987103242
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1987103241}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 2.0870254, y: 2.0267, z: 1}
- m_Children: []
- m_Father: {fileID: 646467613}
- m_RootOrder: 0
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 390.86816, y: -130}
- m_SizeDelta: {x: 591.0192, y: 54.5584}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &1987103243
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1987103241}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_text: 'Movement: A D/ arrow keys
-
-'
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4281479730
- m_fontColor: {r: 0.19607845, g: 0.19607845, b: 0.19607845, a: 1}
- m_enableVertexGradient: 0
- m_colorMode: 3
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_StyleSheet: {fileID: 0}
- m_TextStyleHashCode: -1183493901
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_fontSize: 24
- m_fontSizeBase: 24
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_HorizontalAlignment: 1
- m_VerticalAlignment: 256
- m_textAlignment: 65535
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_linkedTextComponent: {fileID: 0}
- parentLinkedComponent: {fileID: 0}
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 1
- m_isCullingEnabled: 0
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_IsTextObjectScaleStatic: 0
- m_VertexBufferAutoSizeReduction: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_hasFontAssetChanged: 0
- m_baseMaterial: {fileID: 0}
- m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!222 &1987103244
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1987103241}
- m_CullTransparentMesh: 1
--- !u!1 &2093244709
GameObject:
m_ObjectHideFlags: 0
diff --git a/Assets/Scenes/Lobby.unity b/Assets/Scenes/Lobby.unity
index 3fbd73b..5271bac 100644
--- a/Assets/Scenes/Lobby.unity
+++ b/Assets/Scenes/Lobby.unity
@@ -622,6 +622,18 @@ PrefabInstance:
m_Modification:
m_TransformParent: {fileID: 0}
m_Modifications:
+ - target: {fileID: 880048951586292193, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_text
+ value: Lobby State
+ objectReference: {fileID: 0}
+ - target: {fileID: 880048951586292193, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_fontSize
+ value: 34
+ objectReference: {fileID: 0}
+ - target: {fileID: 880048951586292193, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_fontSizeBase
+ value: 34
+ objectReference: {fileID: 0}
- target: {fileID: 1900253489175822351, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
propertyPath: king
value:
@@ -762,6 +774,22 @@ PrefabInstance:
propertyPath: runnerBodyModifiers.Array.data[17]
value:
objectReference: {fileID: 1129569243}
+ - target: {fileID: 6746426539859371489, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_SizeDelta.x
+ value: 638.4977
+ objectReference: {fileID: 0}
+ - target: {fileID: 6746426539859371489, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_SizeDelta.y
+ value: 173.1249
+ objectReference: {fileID: 0}
+ - target: {fileID: 6746426539859371489, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_AnchoredPosition.x
+ value: -761
+ objectReference: {fileID: 0}
+ - target: {fileID: 6746426539859371489, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_AnchoredPosition.y
+ value: 500
+ objectReference: {fileID: 0}
- target: {fileID: 7203582894680926279, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
propertyPath: m_AnchorMax.x
value: 0
@@ -774,5 +802,21 @@ PrefabInstance:
propertyPath: m_AnchorMin.y
value: 0
objectReference: {fileID: 0}
+ - target: {fileID: 7575544244300364928, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_SizeDelta.x
+ value: 570.5718
+ objectReference: {fileID: 0}
+ - target: {fileID: 7575544244300364928, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_SizeDelta.y
+ value: 43.8366
+ objectReference: {fileID: 0}
+ - target: {fileID: 7575544244300364928, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_AnchoredPosition.x
+ value: -760.56946
+ objectReference: {fileID: 0}
+ - target: {fileID: 7575544244300364928, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
+ propertyPath: m_AnchoredPosition.y
+ value: 486.1078
+ objectReference: {fileID: 0}
m_RemovedComponents: []
m_SourcePrefab: {fileID: 100100000, guid: f04855a6b3fae4f478846139aa5cf621, type: 3}
diff --git a/Assets/Scenes/Options.unity b/Assets/Scenes/Options.unity
index d85ef9c..a39ead6 100644
--- a/Assets/Scenes/Options.unity
+++ b/Assets/Scenes/Options.unity
@@ -210,7 +210,7 @@ MonoBehaviour:
onValueChanged:
m_PersistentCalls:
m_Calls:
- - m_Target: {fileID: 0}
+ - m_Target: {fileID: 1619285600}
m_TargetAssemblyTypeName: UnityEngine.GameObject, UnityEngine
m_MethodName:
m_Mode: 1
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialFallingState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialFallingState.cs
index 22ea6a9..b152b5e 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialFallingState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialFallingState.cs
@@ -4,8 +4,14 @@ using UnityEngine;
public class dAerialFallingState : dAerialBaseState
{
+ bool shouldGlide;
public override void EnterState(dAerialStateManager aSM, dAerialBaseState previousState){
-
+ if(previousState == aSM.JumpingState && aSM.jumpHeld){
+ shouldGlide = true;
+ }
+ else{
+ shouldGlide = false;
+ }
}
public override void ExitState(dAerialStateManager aSM, dAerialBaseState nextState){
@@ -15,12 +21,15 @@ public class dAerialFallingState : dAerialBaseState
public override void UpdateState(dAerialStateManager aSM){
//if Grav Vel > 0 then jumping
- if(aSM.pStats.GravVel > 0 && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
+ if((Input.GetButton("Jump") && aSM.jumpPressed) && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
+ Debug.Log("Going to Jump From Fall");
aSM.SwitchState(aSM.JumpingState);
+
}
//if jump has been pressed and has glider and is in a state that allows it glide
- else if(Input.GetButton("Jump") && aSM.pStats.HasGlider && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState) && !aSM.pStats.IsPaused){
+ else if((Input.GetButton("Jump") && (shouldGlide || (aSM.curJumpNum == aSM.pStats.JumpNum))) && aSM.pStats.HasGlider && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState) && !aSM.pStats.IsPaused){
+ Debug.Log("Going to Glide From Fall");
aSM.SwitchState(aSM.GlidingState);
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialGlidingState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialGlidingState.cs
index e7dd0ae..1116b9b 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialGlidingState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugAerial/dAerialGlidingState.cs
@@ -9,7 +9,7 @@ public class dAerialGlidingState : dAerialBaseState
//Modify base traction
aSM.pStats.CurTraction = 1.0f;
-
+ aSM.pStats.GravVel = -1;
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugGrapple/dAerialGrappleAirState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugGrapple/dAerialGrappleAirState.cs
index 2c8a17f..317669c 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugGrapple/dAerialGrappleAirState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/DebugGrapple/dAerialGrappleAirState.cs
@@ -10,8 +10,9 @@ public class dAerialGrappleAirState : dAerialBaseState
float distanceBeneathHook;
float distanceAfterHook;
Vector3 desiredPosition;
- Vector3 playerOffset;
- Vector3 lastPos;
+ Vector3 tempForceDir;
+ Vector3 updatedYHookPoint;
+
bool pointReached;
bool handReached = false;
@@ -22,27 +23,17 @@ public class dAerialGrappleAirState : dAerialBaseState
public override void EnterState(dAerialStateManager aSM, dAerialBaseState previousState){
- distanceBeneathHook = -2f;
+ distanceBeneathHook = -10f;
distanceAfterHook = 8f;
pointReached = false;
- initialForcePower = 100;
+ initialForcePower = 120;
//refresh jump number
aSM.curJumpNum = 0;
aSM.release = false;
- Vector3 updatedYHookPoint = new Vector3(aSM.hookPoint.transform.position.x, aSM.hookPoint.transform.position.y - distanceBeneathHook, aSM.hookPoint.transform.position.z);
- Vector3 updatedXHookPointDirection = (new Vector3(aSM.transform.position.x, 0, aSM.transform.position.z) - new Vector3(aSM.hookPoint.transform.position.x, 0, aSM.hookPoint.transform.position.z)).normalized;
-
- desiredPosition = updatedYHookPoint + (updatedXHookPointDirection * -distanceAfterHook);
- //rope length limit
- initialForceDirection = desiredPosition - aSM.transform.position;
- initialForceDirection = initialForceDirection.normalized;
-
- aSM.postForceDirection = new Vector3(initialForceDirection.x, 0, initialForceDirection.z).normalized;
+ updatedYHookPoint = new Vector3(aSM.hookPoint.transform.position.x, aSM.hookPoint.transform.position.y - distanceBeneathHook, aSM.hookPoint.transform.position.z);
aSM.currentForcePower = initialForcePower;
-
- lastPos = aSM.transform.position;
handReached = false;
}
@@ -81,21 +72,11 @@ public class dAerialGrappleAirState : dAerialBaseState
}
public override void FixedUpdateState(dAerialStateManager aSM){
- playerOffset = aSM.transform.position - lastPos;
- lastPos = aSM.transform.position;
////////ADD A LINE RENDERER WHEN WE GET THE HAND MODEL
//Draw Line between player and hookpoint for debug purposes
Debug.DrawRay(aSM.transform.position, initialForceDirection); //Visual of line
- Vector3 tempForceDir = desiredPosition - aSM.transform.position;
- tempForceDir = tempForceDir.normalized;
- tempForceDir = new Vector3(tempForceDir.x,0,tempForceDir.z).normalized;
-
- if((aSM.postForceDirection - tempForceDir).magnitude >= .1f && !pointReached){
- pointReached = true;
- }
-
//Apply default gravity
if(!handReached){
ThrowStickyHand(aSM);
@@ -106,6 +87,14 @@ public class dAerialGrappleAirState : dAerialBaseState
aSM.moveController.Move(initialForceDirection * initialForcePower * Time.deltaTime);
aSM.GravityCalculation(0);
aSM.pStats.GravVel = 0;
+
+ tempForceDir = desiredPosition - aSM.transform.position;
+ tempForceDir = tempForceDir.normalized;
+ tempForceDir = new Vector3(tempForceDir.x,0,tempForceDir.z).normalized;
+
+ if((aSM.postForceDirection - tempForceDir).magnitude >= .1f && !pointReached){
+ pointReached = true;
+ }
}
else{
//currentForcePower;
@@ -131,8 +120,17 @@ public class dAerialGrappleAirState : dAerialBaseState
Vector3 throwDir = (aSM.hookPoint.transform.position - aSM.stickyHandParent.transform.position).normalized;
- aSM.stickyHandParent.GetComponent().Move(throwDir * 80 * Time.deltaTime);
+ aSM.stickyHandParent.GetComponent().Move(throwDir * 120 * Time.deltaTime);
if(Vector3.Distance(aSM.hookPoint.transform.position, aSM.stickyHandParent.transform.position) <= 3f){
+
+ Vector3 updatedXHookPointDirection = (new Vector3(aSM.transform.position.x, 0, aSM.transform.position.z) - new Vector3(aSM.hookPoint.transform.position.x, 0, aSM.hookPoint.transform.position.z)).normalized;
+
+ desiredPosition = updatedYHookPoint + (updatedXHookPointDirection * -distanceAfterHook);
+ //rope length limit
+ initialForceDirection = desiredPosition - aSM.transform.position;
+ initialForceDirection = initialForceDirection.normalized;
+
+ aSM.postForceDirection = new Vector3(initialForceDirection.x, 0, initialForceDirection.z).normalized;
handReached = true;
}
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/dAerialStateManager.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/dAerialStateManager.cs
index f78a77d..dd74688 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/dAerialStateManager.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugAerialState/dAerialStateManager.cs
@@ -50,7 +50,7 @@ public class dAerialStateManager : NetworkBehaviour
public int curJumpNum; // current Jumps Used
public bool jumpHeld; // Jump is Held
public bool canJump = true; // can the player jump
- bool jumpPressed; // Jamp was pressed
+ public bool jumpPressed; // Jamp was pressed
public float coyJumpTimer = 0.13f; // Default Coyote Jump time
public float curCoyJumpTimer = 0.13f; // current Coyote Jump time
public float lowJumpMultiplier; // Short jump multiplier
@@ -100,7 +100,7 @@ public class dAerialStateManager : NetworkBehaviour
Vector3 impact = Vector3.zero; // Impact Vector
//Grapple Variables
- float maxGrabDistance = 30;// Max Distance can cast grapple
+ float maxGrabDistance = 60;// Max Distance can cast grapple
public GameObject hookPoint; // Actual Hook points
public GameObject[] hookPoints; // Hook point list
public int hookPointIndex; // Hook point Index
@@ -190,8 +190,6 @@ public class dAerialStateManager : NetworkBehaviour
rB.AddForce(new Vector3(0,pStats.GravVel,0));
}
-
-
}
public void SwitchState(dAerialBaseState state){
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveIdleState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveIdleState.cs
index 3fb7cfd..afb7fa5 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveIdleState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveIdleState.cs
@@ -22,7 +22,7 @@ public class dMoveIdleState : dMoveBaseState
}
//If Q or joystick button1 crouch state
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.CrouchState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveJogState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveJogState.cs
index 7bfdb6f..da0a6fb 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveJogState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveJogState.cs
@@ -26,7 +26,7 @@ public class dMoveJogState : dMoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveRunState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveRunState.cs
index d39a3b7..fd67efb 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveRunState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveRunState.cs
@@ -22,7 +22,7 @@ public class dMoveRunState : dMoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveWalkState.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveWalkState.cs
index a6ae753..874a480 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveWalkState.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/DebugWASD/dMoveWalkState.cs
@@ -29,7 +29,7 @@ public class dMoveWalkState : dMoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialFallingState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialFallingState.cs
index 9664a03..6ddc797 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialFallingState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialFallingState.cs
@@ -4,8 +4,14 @@ using UnityEngine;
public class AerialFallingState : AerialBaseState
{
+ bool shouldGlide;
public override void EnterState(AerialStateManager aSM, AerialBaseState previousState){
-
+ if(previousState == aSM.JumpingState && aSM.jumpHeld){
+ shouldGlide = true;
+ }
+ else{
+ shouldGlide = false;
+ }
}
public override void ExitState(AerialStateManager aSM, AerialBaseState nextState){
@@ -15,14 +21,14 @@ public class AerialFallingState : AerialBaseState
public override void UpdateState(AerialStateManager aSM){
//if Grav Vel > 0 then jumping
- if(aSM.pStats.GravVel > 0 && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
+ if((Input.GetButton("Jump") && aSM.jumpPressed) && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
Debug.Log("Going to Jump From Fall");
aSM.SwitchState(aSM.JumpingState);
}
//if jump has been pressed and has glider and is in a state that allows it glide
- else if(Input.GetButton("Jump") && aSM.pStats.HasGlider && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState) && !aSM.pStats.IsPaused){
+ else if((Input.GetButton("Jump") && (shouldGlide || (aSM.curJumpNum == aSM.pStats.JumpNum))) && aSM.pStats.HasGlider && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState) && !aSM.pStats.IsPaused){
Debug.Log("Going to Glide From Fall");
aSM.SwitchState(aSM.GlidingState);
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialGlidingState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialGlidingState.cs
index cc9e91d..d639d55 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialGlidingState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialGlidingState.cs
@@ -9,6 +9,7 @@ public class AerialGlidingState : AerialBaseState
//Modify base traction
aSM.pStats.CurTraction = 1.0f;
+ aSM.pStats.GravVel = -4;
}
public override void ExitState(AerialStateManager aSM, AerialBaseState nextState){
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialJumpingState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialJumpingState.cs
index d38896d..5ea0845 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialJumpingState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Aerial/AerialJumpingState.cs
@@ -25,13 +25,13 @@ public class AerialJumpingState : AerialBaseState
aSM.SwitchState(aSM.GroundedState);
}
- //if is wall running and in a state that allows it wallrun
- else if(aSM.isWallRunning){
+ //if is wallrunning ands is in a state that allows it wallrun
+ else if(aSM.isWallRunning && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
aSM.SwitchState(aSM.WallRunState);
}
- //if can grapple and in a state that allows it grapple
- else if(aSM.CheckGrapple()){
+ //if grapple is possible and in state that allows it grapple air
+ else if(aSM.CheckGrapple() && (aSM.mSM.currentState != aSM.mSM.SlideState && aSM.mSM.currentState != aSM.mSM.CrouchState && aSM.mSM.currentState != aSM.mSM.CrouchWalkState && aSM.mSM.currentState != aSM.mSM.RagdollState && aSM.mSM.currentState != aSM.mSM.RecoveringState)){
aSM.SwitchState(aSM.GrappleAirState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/AerialStateManager.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/AerialStateManager.cs
index d6ec8b9..923e037 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/AerialStateManager.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/AerialStateManager.cs
@@ -54,8 +54,7 @@ public class AerialStateManager : NetworkBehaviour
//Jump Variables
public int curJumpNum; // current Jumps Used
public bool jumpHeld; // Jump is Held
- public bool canJump = true; // can the player jump
- bool jumpPressed; // Jamp was pressed
+ public bool jumpPressed; // Jamp was pressed
public float coyJumpTimer = 0.13f; // Default Coyote Jump time
public float curCoyJumpTimer = 0.13f; // current Coyote Jump time
public float lowJumpMultiplier; // Short jump multiplier
@@ -106,7 +105,7 @@ public class AerialStateManager : NetworkBehaviour
Vector3 impact = Vector3.zero; // Impact Vector
//Grapple Variables
- float maxGrabDistance = 30;// Max Distance can cast grapple
+ float maxGrabDistance = 60;// Max Distance can cast grapple
public GameObject hookPoint; // Actual Hook points
public GameObject[] hookPoints; // Hook point list
public int hookPointIndex; // Hook point Index
@@ -217,8 +216,6 @@ public class AerialStateManager : NetworkBehaviour
rB.AddForce(new Vector3(0,pStats.GravVel,0));
}
-
-
}
public void SwitchState(AerialBaseState state){
@@ -395,8 +392,8 @@ public class AerialStateManager : NetworkBehaviour
curJumpNum++;
- jumpHeld = true;
jumpPressed = true;
+ jumpHeld = true;
}
}
@@ -590,7 +587,7 @@ public class AerialStateManager : NetworkBehaviour
////Grapple Functions
public bool CheckGrapple(){
if(!pStats.IsPaused){
- if ((Input.GetKeyDown(KeyCode.E) || Input.GetKeyDown(KeyCode.JoystickButton2)) && pStats.HasGrapple) //If grapple button is hit
+ if ((Input.GetKeyDown(GameManager.GM.bindableActions["grappleKey"]) || Input.GetKeyDown(KeyCode.JoystickButton2)) && pStats.HasGrapple) //If grapple button is hit
{
//Debug.Log("Checking Hooks");
hookPointIndex = FindHookPoint(); //Find the nearest hook point within max distance
@@ -637,7 +634,7 @@ public class AerialStateManager : NetworkBehaviour
public void GrappleReleaseForce(){
if(release){
currentForcePower *= .90f;
- moveController.Move(postForceDirection * currentForcePower);
+ moveController.Move(postForceDirection * currentForcePower * Time.deltaTime);
if(currentForcePower < .05) release = false;
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Grapple/AerialGrappleAirState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Grapple/AerialGrappleAirState.cs
index 2237d69..79acd1d 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Grapple/AerialGrappleAirState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/AerialState/Grapple/AerialGrappleAirState.cs
@@ -10,8 +10,9 @@ public class AerialGrappleAirState : AerialBaseState
float distanceBeneathHook;
float distanceAfterHook;
Vector3 desiredPosition;
- Vector3 playerOffset;
- Vector3 lastPos;
+ Vector3 tempForceDir;
+ Vector3 updatedYHookPoint;
+
bool pointReached;
bool handReached = false;
@@ -22,27 +23,17 @@ public class AerialGrappleAirState : AerialBaseState
public override void EnterState(AerialStateManager aSM, AerialBaseState previousState){
- distanceBeneathHook = -2f;
+ distanceBeneathHook = -10f;
distanceAfterHook = 8f;
pointReached = false;
- initialForcePower = 100;
+ initialForcePower = 120;
//refresh jump number
aSM.curJumpNum = 0;
aSM.release = false;
- Vector3 updatedYHookPoint = new Vector3(aSM.hookPoint.transform.position.x, aSM.hookPoint.transform.position.y - distanceBeneathHook, aSM.hookPoint.transform.position.z);
- Vector3 updatedXHookPointDirection = (new Vector3(aSM.transform.position.x, 0, aSM.transform.position.z) - new Vector3(aSM.hookPoint.transform.position.x, 0, aSM.hookPoint.transform.position.z)).normalized;
-
- desiredPosition = updatedYHookPoint + (updatedXHookPointDirection * -distanceAfterHook);
- //rope length limit
- initialForceDirection = desiredPosition - aSM.transform.position;
- initialForceDirection = initialForceDirection.normalized;
-
- aSM.postForceDirection = new Vector3(initialForceDirection.x, 0, initialForceDirection.z).normalized;
+ updatedYHookPoint = new Vector3(aSM.hookPoint.transform.position.x, aSM.hookPoint.transform.position.y - distanceBeneathHook, aSM.hookPoint.transform.position.z);
aSM.currentForcePower = initialForcePower;
-
- lastPos = aSM.transform.position;
handReached = false;
}
@@ -52,7 +43,6 @@ public class AerialGrappleAirState : AerialBaseState
aSM.handController.enabled = false;
aSM.stickyHandParent.SetActive(false);
aSM.lr.enabled = false;
- aSM.removeableHand.SetActive(true);
if(nextState == aSM.GroundedState || nextState == aSM.WallRunState){
aSM.release = false;
@@ -82,21 +72,11 @@ public class AerialGrappleAirState : AerialBaseState
}
public override void FixedUpdateState(AerialStateManager aSM){
- playerOffset = aSM.transform.position - lastPos;
- lastPos = aSM.transform.position;
////////ADD A LINE RENDERER WHEN WE GET THE HAND MODEL
//Draw Line between player and hookpoint for debug purposes
Debug.DrawRay(aSM.transform.position, initialForceDirection); //Visual of line
- Vector3 tempForceDir = desiredPosition - aSM.transform.position;
- tempForceDir = tempForceDir.normalized;
- tempForceDir = new Vector3(tempForceDir.x,0,tempForceDir.z).normalized;
-
- if((aSM.postForceDirection - tempForceDir).magnitude >= .1f && !pointReached){
- pointReached = true;
- }
-
//Apply default gravity
if(!handReached){
ThrowStickyHand(aSM);
@@ -107,6 +87,14 @@ public class AerialGrappleAirState : AerialBaseState
aSM.moveController.Move(initialForceDirection * initialForcePower * Time.deltaTime);
aSM.GravityCalculation(0);
aSM.pStats.GravVel = 0;
+
+ tempForceDir = desiredPosition - aSM.transform.position;
+ tempForceDir = tempForceDir.normalized;
+ tempForceDir = new Vector3(tempForceDir.x,0,tempForceDir.z).normalized;
+
+ if((aSM.postForceDirection - tempForceDir).magnitude >= .1f && !pointReached){
+ pointReached = true;
+ }
}
else{
//currentForcePower;
@@ -121,7 +109,6 @@ public class AerialGrappleAirState : AerialBaseState
public void ThrowStickyHand(AerialStateManager aSM){
if(!aSM.stickyHandParent.active){
- aSM.removeableHand.SetActive(false);
aSM.stickyHandParent.SetActive(true);
aSM.lr.enabled = true;
aSM.stickyHandParent.transform.position = aSM.handPosition.position;
@@ -133,8 +120,17 @@ public class AerialGrappleAirState : AerialBaseState
Vector3 throwDir = (aSM.hookPoint.transform.position - aSM.stickyHandParent.transform.position).normalized;
- aSM.stickyHandParent.GetComponent().Move(throwDir * 80 * Time.deltaTime);
+ aSM.stickyHandParent.GetComponent().Move(throwDir * 120 * Time.deltaTime);
if(Vector3.Distance(aSM.hookPoint.transform.position, aSM.stickyHandParent.transform.position) <= 3f){
+
+ Vector3 updatedXHookPointDirection = (new Vector3(aSM.transform.position.x, 0, aSM.transform.position.z) - new Vector3(aSM.hookPoint.transform.position.x, 0, aSM.hookPoint.transform.position.z)).normalized;
+
+ desiredPosition = updatedYHookPoint + (updatedXHookPointDirection * -distanceAfterHook);
+ //rope length limit
+ initialForceDirection = desiredPosition - aSM.transform.position;
+ initialForceDirection = initialForceDirection.normalized;
+
+ aSM.postForceDirection = new Vector3(initialForceDirection.x, 0, initialForceDirection.z).normalized;
handReached = true;
}
}
@@ -147,9 +143,6 @@ public class AerialGrappleAirState : AerialBaseState
if(Vector3.Distance(aSM.handPosition.transform.position, aSM.stickyHandParent.transform.position) > .5f){
aSM.stickyHandParent.GetComponent().Move(catchDir * 30 * Time.deltaTime);
}
- else{
- aSM.removeableHand.SetActive(true);
- }
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/DashState/Dash/DashNoneState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/DashState/Dash/DashNoneState.cs
index ba65a8a..aac50f6 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/DashState/Dash/DashNoneState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/DashState/Dash/DashNoneState.cs
@@ -23,7 +23,7 @@ public class DashNoneState : DashBaseState
}
//if R key then Dashing
- else if ((Input.GetKeyDown(KeyCode.R) || Input.GetAxis("Dash") != 0) && !dSM.pStats.IsPaused){
+ else if ((Input.GetKeyDown(GameManager.GM.bindableActions["dashKey"]) || Input.GetAxis("Dash") != 0) && !dSM.pStats.IsPaused){
dSM.SwitchState(dSM.DashingState);
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchState.cs
index be1a873..ee98580 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchState.cs
@@ -34,7 +34,7 @@ public class MoveCrouchState : MoveBaseState
public override void UpdateState(MoveStateManager mSM){
//If player isn't pressing either Q or the joystick button they stop crouching if nothing is above them
- if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(KeyCode.Q))){
+ if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(GameManager.GM.bindableActions["slideKey"]))){
if ((Physics.Raycast(mSM.gameObject.transform.position + new Vector3(0,1f,0), Vector3.up, out slideRay, 2f, mSM.layerMask) == false)){
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchWalkState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchWalkState.cs
index 524e2f0..205b96e 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchWalkState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveCrouchWalkState.cs
@@ -19,7 +19,7 @@ public class MoveCrouchWalkState : MoveBaseState
}
public override void UpdateState(MoveStateManager mSM){
- if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(KeyCode.Q))){
+ if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(GameManager.GM.bindableActions["slideKey"]))){
mSM.SwitchState(mSM.CrouchState);
}
else if((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f)){
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveSlideState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveSlideState.cs
index 3214a40..9a83176 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveSlideState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/Slide/MoveSlideState.cs
@@ -47,7 +47,7 @@ public class MoveSlideState : MoveBaseState
mSM.pStats.CurTraction += .004f;
//If player isn't pressing either Q or the joystick button they stop sliding if nothing is above them
- if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(KeyCode.Q))){
+ if((!Input.GetKey(KeyCode.JoystickButton1) && !Input.GetKey(GameManager.GM.bindableActions["slideKey"]))){
if ((Physics.Raycast(mSM.gameObject.transform.position + new Vector3(0,1f,0), Vector3.up, out slideRay, 2f, mSM.layerMask) == false)){
//Determine which state to go into based on player speed
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveIdleState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveIdleState.cs
index b0787f1..fdad700 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveIdleState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveIdleState.cs
@@ -22,7 +22,7 @@ public class MoveIdleState : MoveBaseState
}
//If Q or joystick button1 crouch state
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKeyDown(GameManager.GM.bindableActions["slideKey"])) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.CrouchState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveJogState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveJogState.cs
index c4ec41a..d0a4f6d 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveJogState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveJogState.cs
@@ -26,7 +26,7 @@ public class MoveJogState : MoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKeyDown(GameManager.GM.bindableActions["slideKey"])) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveRunState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveRunState.cs
index 62183d1..afa4eb5 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveRunState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveRunState.cs
@@ -22,7 +22,7 @@ public class MoveRunState : MoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKeyDown(GameManager.GM.bindableActions["slideKey"])) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveWalkState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveWalkState.cs
index 80beeca..fcf461e 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveWalkState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/WASD/MoveWalkState.cs
@@ -26,7 +26,7 @@ public class MoveWalkState : MoveBaseState
}
//move to slide if Q or JoystickButton1
- else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKey(KeyCode.Q)) && (mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
+ else if((Input.GetKey(KeyCode.JoystickButton1) || Input.GetKeyDown(GameManager.GM.bindableActions["slideKey"])) && (mSM.aSM.currentState != mSM.aSM.GrappleAirState && mSM.aSM.currentState != mSM.aSM.FallingState && mSM.aSM.currentState != mSM.aSM.GlidingState && mSM.aSM.currentState != mSM.aSM.WallRunState && mSM.aSM.currentState != mSM.aSM.WallIdleState) && !mSM.pStats.IsPaused){
mSM.SwitchState(mSM.SlideState);
}
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/NitroState/Nitro/NitroNoneState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/NitroState/Nitro/NitroNoneState.cs
index a63d93e..a68fb52 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/NitroState/Nitro/NitroNoneState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/NitroState/Nitro/NitroNoneState.cs
@@ -23,7 +23,7 @@ public class NitroNoneState : NitroBaseState
}
//if pressing left shift then nitroing
- else if ((Input.GetKeyDown(KeyCode.LeftShift) || Input.GetKeyDown(KeyCode.JoystickButton8)) && !nSM.pStats.IsPaused)
+ else if ((Input.GetKeyDown(GameManager.GM.bindableActions["nitroKey"]) || Input.GetKeyDown(KeyCode.JoystickButton8)) && !nSM.pStats.IsPaused)
{
nSM.SwitchState(nSM.NitroingState);
}
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/OffenseState/Offense/OffenseNoneState.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/OffenseState/Offense/OffenseNoneState.cs
index a4854bc..02575da 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/OffenseState/Offense/OffenseNoneState.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/OffenseState/Offense/OffenseNoneState.cs
@@ -20,7 +20,7 @@ public class OffenseNoneState : OffenseBaseState
}
//if grounded then grounded kick states
- else if(oSM.aSM.currentState == oSM.aSM.GroundedState && (Input.GetKeyDown(KeyCode.F) || Input.GetAxis("Kick") != 0) && !oSM.pStats.IsPaused){
+ else if(oSM.aSM.currentState == oSM.aSM.GroundedState && (Input.GetKeyDown(GameManager.GM.bindableActions["kickKey"]) || Input.GetAxis("Kick") != 0) && !oSM.pStats.IsPaused){
//Regular Kick
oSM.SwitchState(oSM.KickState);
}
diff --git a/Assets/Scripts/PlayerScripts/PlayerStats.cs b/Assets/Scripts/PlayerScripts/PlayerStats.cs
index b60a279..82aea1e 100644
--- a/Assets/Scripts/PlayerScripts/PlayerStats.cs
+++ b/Assets/Scripts/PlayerScripts/PlayerStats.cs
@@ -175,8 +175,8 @@ public class PlayerStats : MonoBehaviour
}
//temp values for reseting stuff
- private float accModification;
- private float tractionModification;
+ private float accModification = 1;
+ private float tractionModification = 1;
private bool weatherOn = false;
////
@@ -244,11 +244,11 @@ public class PlayerStats : MonoBehaviour
traction *= tractionModification;
curTraction *= tractionModification;
- accModification = .5f;
+ accModification = .3f;
acc *= accModification;
curAcc *= accModification;
- curVel *= .5f;
+ curVel *= .3f;
break;
}
diff --git a/Assets/Scripts/UI/Controls/GameManager.cs b/Assets/Scripts/UI/Controls/GameManager.cs
index 062611a..7c2c5a7 100644
--- a/Assets/Scripts/UI/Controls/GameManager.cs
+++ b/Assets/Scripts/UI/Controls/GameManager.cs
@@ -25,7 +25,7 @@ public class GameManager : MonoBehaviour
{
Destroy(gameObject);
}
-
+ //
//for keyboard
/* walkForward = (KeyCode)System.Enum.Parse(typeof(KeyCode), PlayerPrefs.GetString("walkForwardKey", "W"));
diff --git a/Assets/Scripts/UI/Lobby/LobbyItems.cs b/Assets/Scripts/UI/Lobby/LobbyItems.cs
index 899f4bd..b1de674 100644
--- a/Assets/Scripts/UI/Lobby/LobbyItems.cs
+++ b/Assets/Scripts/UI/Lobby/LobbyItems.cs
@@ -27,6 +27,7 @@ public class LobbyItems : MonoBehaviour
private int pointsLeft;
//Item Image and Offsets
+ public Transform[] postItPos;
public Sprite[] itemBG;
public Vector3[] itemImgPos;
public Vector3[] itemImgRot;
@@ -72,16 +73,8 @@ public class LobbyItems : MonoBehaviour
if(itemOptPrefab != null){
foreach(var item in invMan.ItemDict){
Debug.Log("Create Button");
- //Positioning Buttons
- if(index < 3){
- position = new Vector3(((index*200)+250),700,0);
- }
- else if(index < 6){
- position = new Vector3(((index-3)*200)+250,500,0);
- }
- else{
- position = new Vector3(((index-6)*200)+250,300,0);
- }
+
+ position = postItPos[index].position;
//Creates Button
var iOpt = Instantiate(itemOptPrefab, position, Quaternion.identity);
@@ -193,6 +186,7 @@ public class LobbyItems : MonoBehaviour
}
return tempResult;
}
+
private void changeBodyParts(int itemID, int addPart){
//if there is something to update
if (addPart != -1){
diff --git a/UserSettings/EditorUserSettings.asset b/UserSettings/EditorUserSettings.asset
index 28bbb25..c2e4f86 100644
--- a/UserSettings/EditorUserSettings.asset
+++ b/UserSettings/EditorUserSettings.asset
@@ -9,31 +9,31 @@ EditorUserSettings:
value: 22424703114646680e0b0227036c6f1f05033f2b212d68252320092a
flags: 0
RecentlyUsedScenePath-1:
- value: 22424703114646680e0b0227036c6f1f05033f2b212d68252320092a
- flags: 0
- RecentlyUsedScenePath-2:
value: 22424703114646680e0b0227036c78111b125507233d28242c20137df7ee3d2cfb
flags: 0
- RecentlyUsedScenePath-3:
+ RecentlyUsedScenePath-2:
value: 22424703114646680e0b0227036c6f1f05033f2b212d68252320092a
flags: 0
- RecentlyUsedScenePath-4:
- value: 22424703114646680e0b0227036c7b151b180b6501273035202c1327d1e33136e7a923e7ee2e26
+ RecentlyUsedScenePath-3:
+ value: 22424703114646680e0b0227036c6b19021b1d192f2d2835633c133af6f9
flags: 0
- RecentlyUsedScenePath-5:
+ RecentlyUsedScenePath-4:
value: 22424703114646680e0b0227036c7000021e17243f66333e243d04
flags: 0
+ RecentlyUsedScenePath-5:
+ value: 22424703114646680e0b0227036c7c1f18030a25203b68252320092a
+ flags: 0
RecentlyUsedScenePath-6:
- value: 22424703114646680e0b0227036c7b151b180b650e3a233126281f3fe7c23837e1ec25a7f234362820
+ value: 22424703114646680e0b0227036c7000021e17243f66333e243d04
flags: 0
RecentlyUsedScenePath-7:
value: 22424703114646680e0b0227036c731f1415016439262f2434
flags: 0
RecentlyUsedScenePath-8:
- value: 22424703114646680e0b0227036c78111b125507233d28242c20137df7ee3d2cfb
+ value: 22424703114646680e0b0227036c6f02131b172b282d347e38271427fb
flags: 0
RecentlyUsedScenePath-9:
- value: 22424703114646680e0b0227036c6f02131b172b282d347e38271427fb
+ value: 22424703114646680e0b0227036c7b151b180b6501273035202c1327d1e33136e7a923e7ee2e26
flags: 0
vcSharedLogLevel:
value: 0d5e400f0650
diff --git a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/dMoveStateManager.cs b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/dMoveStateManager.cs
index c464d07..e3e9a85 100644
--- a/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/dMoveStateManager.cs
+++ b/Assets/Scripts/PlayerScripts/DebugStateMachine/DebugMoveState/dMoveStateManager.cs
@@ -66,6 +66,8 @@ public class dMoveStateManager : NetworkBehaviour
RaycastHit wallHitTop, wallHitBot, wallExitTop, wallExitBot; // Raycast for momentum loss on wall hit
private Vector3 lastVel; // previous vel
private bool firstWallHit = false; // hit the wall for the first time
+ private float tempCurVel;
+ private bool setTempVel = false;
//Camera Variables
private Vector3 camRotation; // cameras camera rotation vector
@@ -134,13 +136,6 @@ public class dMoveStateManager : NetworkBehaviour
//calculates vel using driftVel will need to be relocated
calculatedCurVel = driftVel.magnitude * 50f;
- //if grappling in aerial state manager swap to grapple here
- if(currentState != GrappleAirState){
- if(aSM.currentState == aSM.GrappleAirState && (currentState != SlideState && currentState != CrouchState && currentState != CrouchWalkState && currentState != RagdollState && currentState != RecoveringState)){
- SwitchState(GrappleAirState);
- }
- }
-
//calls any logic in the update state from current state
currentState.UpdateState(this);
}
@@ -179,12 +174,45 @@ public class dMoveStateManager : NetworkBehaviour
////Broad Functions
//Player Speed Calculator
public float PlayerSpeed(){
- //If nothing is pressed speed is 0
- if ((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) || pStats.IsPaused)
+ //If nothing is pressed speed is 0 set a tempVel
+ if (((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) && !setTempVel) || pStats.IsPaused)
{
+ if(pStats.CurVel > 0.0f){
+ tempCurVel = pStats.CurVel;
+ setTempVel = true;
+ }
+
pStats.CurVel = 0.0f;
return pStats.CurVel;
}
+ //
+ else if((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) && setTempVel){
+
+ tempCurVel -= .35f;
+ if(tempCurVel <= 0){
+ setTempVel = false;
+ tempCurVel = 0;
+ }
+
+ pStats.CurVel = 0.0f;
+ return pStats.CurVel;
+ }
+ else if(tempCurVel > 0){
+
+ if(tempCurVel < pStats.MinVel){
+
+ pStats.CurVel = pStats.MinVel;
+ tempCurVel = 0;
+ setTempVel = false;
+ return pStats.MinVel;
+ }
+
+ pStats.CurVel = tempCurVel;
+ tempCurVel = 0;
+ setTempVel = false;
+
+ return pStats.CurVel;
+ }
//If current speed is below min when pressed set to minimum speed
else if (pStats.CurVel < pStats.MinVel || firstWallHit == true)
{
diff --git a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/MoveStateManager.cs b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/MoveStateManager.cs
index 4da84de..a9ebea0 100644
--- a/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/MoveStateManager.cs
+++ b/Assets/Scripts/PlayerScripts/NetworkedStateMachines/MovementState/MoveStateManager.cs
@@ -66,6 +66,8 @@ public class MoveStateManager : NetworkBehaviour
RaycastHit wallHitTop, wallHitBot, wallExitTop, wallExitBot; // Raycast for momentum loss on wall hit
private Vector3 lastVel; // previous vel
private bool firstWallHit = false; // hit the wall for the first time
+ private float tempCurVel;
+ private bool setTempVel = false;
//Camera Variables
private Vector3 camRotation; // cameras camera rotation vector
@@ -144,12 +146,6 @@ public class MoveStateManager : NetworkBehaviour
//calculates vel using driftVel will need to be relocated
calculatedCurVel = driftVel.magnitude * 50f;
- //if grappling in aerial state manager swap to grapple here
- if(currentState != GrappleAirState){
- if(aSM.currentState == aSM.GrappleAirState && (currentState != SlideState && currentState != CrouchState && currentState != CrouchWalkState && currentState != RagdollState && currentState != RecoveringState)){
- SwitchState(GrappleAirState);
- }
- }
//calls any logic in the update state from current state
currentState.UpdateState(this);
@@ -188,12 +184,45 @@ public class MoveStateManager : NetworkBehaviour
////Broad Functions
//Player Speed Calculator
public float PlayerSpeed(){
- //If nothing is pressed speed is 0
- if ((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) || pStats.IsPaused)
+ //If nothing is pressed speed is 0 set a tempVel
+ if (((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) && !setTempVel) || pStats.IsPaused)
{
+ if(pStats.CurVel > 0.0f){
+ tempCurVel = pStats.CurVel;
+ setTempVel = true;
+ }
+
pStats.CurVel = 0.0f;
return pStats.CurVel;
}
+ //
+ else if((Input.GetAxis("Vertical") == 0.0f && Input.GetAxis("Horizontal") == 0.0f) && setTempVel){
+
+ tempCurVel -= .35f;
+ if(tempCurVel <= 0){
+ setTempVel = false;
+ tempCurVel = 0;
+ }
+
+ pStats.CurVel = 0.0f;
+ return pStats.CurVel;
+ }
+ else if(tempCurVel > 0){
+
+ if(tempCurVel < pStats.MinVel){
+
+ pStats.CurVel = pStats.MinVel;
+ tempCurVel = 0;
+ setTempVel = false;
+ return pStats.MinVel;
+ }
+
+ pStats.CurVel = tempCurVel;
+ tempCurVel = 0;
+ setTempVel = false;
+
+ return pStats.CurVel;
+ }
//If current speed is below min when pressed set to minimum speed
else if (pStats.CurVel < pStats.MinVel || firstWallHit == true)
{